# -*- coding: utf-8 -*-
"""
Create, Read, Update, Delete functionality

"""

from sqlalchemy.orm import Session
from fastapi.responses import JSONResponse
from . import models
from .schemas import TimeseriesCreate


def get_timeseries(db: Session, timeseries_id: int):
    db_object = db.query(models.Timeseries).filter(models.Timeseries.id == timeseries_id).first()
    # there is a mismatch with additional_metadata
    if db_object:
        db_object.additional_metadata = str(db_object.additional_metadata)
    return db_object


def get_all_timeseries(db: Session, skip : int = 0, limit: int = None):
    db_objects = db.query(models.Timeseries).offset(skip).limit(limit).all()
    for db_object in db_objects:
        # there is a mismatch with additional_metadata
        db_object.additional_metadata = str(db_object.additional_metadata)
    return db_objects


def get_timeseries_by_unique_constraints(db: Session, station_id: int, variable_id: int, label: str):
    with db.no_autoflush:
        db_object = db.query(models.Timeseries).filter(models.Timeseries.station_id == station_id) \
                                          .filter(models.Timeseries.variable_id == variable_id) \
                                          .filter(models.Timeseries.label == label.strip()) \
                                          .first()
        print(db_object)
        # there is a mismatch with additional_metadata
        if db_object:
            db_object.additional_metadata = str(db_object.additional_metadata)
    return db_object


def create_timeseries(db: Session, timeseries: TimeseriesCreate):
    db_timeseries = models.Timeseries (**timeseries.dict())
    # there's also a mismatch with additional_metadata --> BUT: this should not be switched back!
    # in upload command, we have now: "additional_metadata": "{}"
    # but return from this method gives: "additional_metadata": {}
    # ==> there is a mismatch between model(JSONB) and schema(JSON)
    db_timeseries.additional_metadata = str(db_timeseries.additional_metadata)
    db.add(db_timeseries)
    result = db.commit()
    db.refresh(db_timeseries)
    return db_timeseries
